==> shoppingMall-dao-6.0.1-sources.jar: com/viontech/mall/model/FaceRecognition.java <==
package com.viontech.mall.model;

import com.viontech.keliu.base.BaseModel;

import java.util.Date;

public class FaceRecognition extends BaseModel {
    private Long id;

    private Long deviceId;

    private Long channelId;

    private Long gateId;

    private Long personId;

    private String deviceSerialnum;

    private String channelSerialnum;

    private Short personType;

    private String facePic;

    private String facePicExt;

    private String bodyPicExt;

    private String bodyPic;

    private String showbodyPic;

    private Short mood;

    private Short age;

    private Short gender;

    private Short direction;

    private Date counttime;

    private Date countdate;

    private Date modifyTime;

    private Date createTime;

    private Long mallId;

    private Long accountId;

    private String personUnid;

    private String showbodyPicExt;

    private Short status;

    private String facePath;

    private String bodyPath;

    private String faceFeature;

    private String bodyFeature;

    private String trackInfo;

    private Integer trackTime;

    private Short happyConf;

    private Short historyArrivalCount;

    private Short todayArrivalCount;

    private String trackPath;

    private String unid;

    private Float faceScore;

    private Short faceType;

    private Gate gate;

    private Person person;

    private Device device;

    private Channel channel;

    private Mall mall;

    private Account account;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(Long deviceId) {
        this.deviceId = deviceId;
    }

    public Long getChannelId() {
        return channelId;
    }

    public void setChannelId(Long channelId) {
        this.channelId = channelId;
    }

    public Long getGateId() {
        return gateId;
    }

    public void setGateId(Long gateId) {
        this.gateId = gateId;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }

    public String getDeviceSerialnum() {
        return deviceSerialnum;
    }

    public void setDeviceSerialnum(String deviceSerialnum) {
        this.deviceSerialnum = deviceSerialnum == null ? null : deviceSerialnum.trim();
    }

    public String getChannelSerialnum() {
        return channelSerialnum;
    }

    public void setChannelSerialnum(String channelSerialnum) {
        this.channelSerialnum = channelSerialnum == null ? null : channelSerialnum.trim();
    }

    public Short getPersonType() {
        return personType;
    }

    public void setPersonType(Short personType) {
        this.personType = personType;
    }

    public String getFacePic() {
        return facePic;
    }

    public void setFacePic(String facePic) {
        this.facePic = facePic == null ? null : facePic.trim();
    }

    public String getFacePicExt() {
        return facePicExt;
    }

    public void setFacePicExt(String facePicExt) {
        this.facePicExt = facePicExt == null ? null : facePicExt.trim();
    }

    public String getBodyPicExt() {
        return bodyPicExt;
    }

    public void setBodyPicExt(String bodyPicExt) {
        this.bodyPicExt = bodyPicExt == null ? null : bodyPicExt.trim();
    }

    public String getBodyPic() {
        return bodyPic;
    }

    public void setBodyPic(String bodyPic) {
        this.bodyPic = bodyPic == null ? null : bodyPic.trim();
    }

    public String getShowbodyPic() {
        return showbodyPic;
    }

    public void setShowbodyPic(String showbodyPic) {
        this.showbodyPic = showbodyPic == null ? null : showbodyPic.trim();
    }

    public Short getMood() {
        return mood;
    }

    public void setMood(Short mood) {
        this.mood = mood;
    }

    public Short getAge() {
        return age;
    }

    public void setAge(Short age) {
        this.age = age;
    }

    public Short getGender() {
        return gender;
    }

    public void setGender(Short gender) {
        this.gender = gender;
    }

    public Short getDirection() {
        return direction;
    }

    public void setDirection(Short direction) {
        this.direction = direction;
    }

    public Date getCounttime() {
        return counttime;
    }

    public void setCounttime(Date counttime) {
        this.counttime = counttime;
    }

    public Date getCountdate() {
        return countdate;
    }

    public void setCountdate(Date countdate) {
        this.countdate = countdate;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Long getMallId() {
        return mallId;
    }

    public void setMallId(Long mallId) {
        this.mallId = mallId;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getPersonUnid() {
        return personUnid;
    }

    public void setPersonUnid(String personUnid) {
        this.personUnid = personUnid == null ? null : personUnid.trim();
    }

    public String getShowbodyPicExt() {
        return showbodyPicExt;
    }

    public void setShowbodyPicExt(String showbodyPicExt) {
        this.showbodyPicExt = showbodyPicExt == null ? null : showbodyPicExt.trim();
    }

    public Short getStatus() {
        return status;
    }

    public void setStatus(Short status) {
        this.status = status;
    }

    public String getFacePath() {
        return facePath;
    }

    public void setFacePath(String facePath) {
        this.facePath = facePath == null ? null : facePath.trim();
    }

    public String getBodyPath() {
        return bodyPath;
    }

    public void setBodyPath(String bodyPath) {
        this.bodyPath = bodyPath == null ? null : bodyPath.trim();
    }

    public String getFaceFeature() {
        return faceFeature;
    }

    public void setFaceFeature(String faceFeature) {
        this.faceFeature = faceFeature == null ? null : faceFeature.trim();
    }

    public String getBodyFeature() {
        return bodyFeature;
    }

    public void setBodyFeature(String bodyFeature) {
        this.bodyFeature = bodyFeature == null ? null : bodyFeature.trim();
    }

    public String getTrackInfo() {
        return trackInfo;
    }

    public void setTrackInfo(String trackInfo) {
        this.trackInfo = trackInfo == null ? null : trackInfo.trim();
    }

    public Integer getTrackTime() {
        return trackTime;
    }

    public void setTrackTime(Integer trackTime) {
        this.trackTime = trackTime;
    }

    public Short getHappyConf() {
        return happyConf;
    }

    public void setHappyConf(Short happyConf) {
        this.happyConf = happyConf;
    }

    public Short getHistoryArrivalCount() {
        return historyArrivalCount;
    }

    public void setHistoryArrivalCount(Short historyArrivalCount) {
        this.historyArrivalCount = historyArrivalCount;
    }

    public Short getTodayArrivalCount() {
        return todayArrivalCount;
    }

    public void setTodayArrivalCount(Short todayArrivalCount) {
        this.todayArrivalCount = todayArrivalCount;
    }

    public String getTrackPath() {
        return trackPath;
    }

    public void setTrackPath(String trackPath) {
        this.trackPath = trackPath == null ? null : trackPath.trim();
    }

    public String getUnid() {
        return unid;
    }

    public void setUnid(String unid) {
        this.unid = unid == null ? null : unid.trim();
    }

    public Float getFaceScore() {
        return faceScore;
    }

    public void setFaceScore(Float faceScore) {
        this.faceScore = faceScore;
    }

    public Short getFaceType() {
        return faceType;
    }

    public void setFaceType(Short faceType) {
        this.faceType = faceType;
    }

    public Gate getGate() {
        return gate;
    }

    public void setGate(Gate gate) {
        this.gate = gate;
    }

    public Person getPerson() {
        return person;
    }

    public void setPerson(Person person) {
        this.person = person;
    }

    public Device getDevice() {
        return device;
    }

    public void setDevice(Device device) {
        this.device = device;
    }

    public Channel getChannel() {
        return channel;
    }

    public void setChannel(Channel channel) {
        this.channel = channel;
    }

    public Mall getMall() {
        return mall;
    }

    public void setMall(Mall mall) {
        this.mall = mall;
    }

    public Account getAccount() {
        return account;
    }

    public void setAccount(Account account) {
        this.account = account;
    }
}

==> shoppingMall-dao-6.0.5-sources.jar: com/viontech/mall/model/FaceRecognition.java <==
package com.viontech.mall.model;

import com.viontech.keliu.base.BaseModel;
import java.util.Date;

public class FaceRecognition extends BaseModel {
    private Long id;

    private Long deviceId;

    private Long channelId;

    private Long gateId;

    private Long personId;

    private String deviceSerialnum;

    private String channelSerialnum;

    private Short personType;

    private String facePic;

    private String facePicExt;

    private String bodyPicExt;

    private String bodyPic;

    private String showbodyPic;

    private Short mood;

    private Short age;

    private Short gender;

    private Short direction;

    private Date counttime;

    private Date countdate;

    private Date modifyTime;

    private Date createTime;

    private Long mallId;

    private Long accountId;

    private String personUnid;

    private String showbodyPicExt;

    private Short status;

    private String facePath;

    private String bodyPath;

    private String faceFeature;

    private String bodyFeature;

    private String trackInfo;

    private Integer trackTime;

    private Short happyConf;

    private Short historyArrivalCount;

    private Short todayArrivalCount;

    private String trackPath;

    private String unid;

    private Float faceScore;

    private Short faceType;

    private Long flag;

    private Device device;

    private Channel channel;

    private Gate gate;

    private Person person;

    private Mall mall;

    private Account account;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(Long deviceId) {
        this.deviceId = deviceId;
    }

    public Long getChannelId() {
        return channelId;
    }

    public void setChannelId(Long channelId) {
        this.channelId = channelId;
    }

    public Long getGateId() {
        return gateId;
    }

    public void setGateId(Long gateId) {
        this.gateId = gateId;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }

    public String getDeviceSerialnum() {
        return deviceSerialnum;
    }

    public void setDeviceSerialnum(String deviceSerialnum) {
        this.deviceSerialnum = deviceSerialnum == null ? null : deviceSerialnum.trim();
    }

    public String getChannelSerialnum() {
        return channelSerialnum;
    }

    public void setChannelSerialnum(String channelSerialnum) {
        this.channelSerialnum = channelSerialnum == null ? null : channelSerialnum.trim();
    }

    public Short getPersonType() {
        return personType;
    }

    public void setPersonType(Short personType) {
        this.personType = personType;
    }

    public String getFacePic() {
        return facePic;
    }

    public void setFacePic(String facePic) {
        this.facePic = facePic == null ? null : facePic.trim();
    }

    public String getFacePicExt() {
        return facePicExt;
    }

    public void setFacePicExt(String facePicExt) {
        this.facePicExt = facePicExt == null ? null : facePicExt.trim();
    }

    public String getBodyPicExt() {
        return bodyPicExt;
    }

    public void setBodyPicExt(String bodyPicExt) {
        this.bodyPicExt = bodyPicExt == null ? null : bodyPicExt.trim();
    }

    public String getBodyPic() {
        return bodyPic;
    }

    public void setBodyPic(String bodyPic) {
        this.bodyPic = bodyPic == null ? null : bodyPic.trim();
    }

    public String getShowbodyPic() {
        return showbodyPic;
    }

    public void setShowbodyPic(String showbodyPic) {
        this.showbodyPic = showbodyPic == null ? null : showbodyPic.trim();
    }

    public Short getMood() {
        return mood;
    }

    public void setMood(Short mood) {
        this.mood = mood;
    }

    public Short getAge() {
        return age;
    }

    public void setAge(Short age) {
        this.age = age;
    }

    public Short getGender() {
        return gender;
    }

    public void setGender(Short gender) {
        this.gender = gender;
    }

    public Short getDirection() {
        return direction;
    }

    public void setDirection(Short direction) {
        this.direction = direction;
    }

    public Date getCounttime() {
        return counttime;
    }

    public void setCounttime(Date counttime) {
        this.counttime = counttime;
    }

    public Date getCountdate() {
        return countdate;
    }

    public void setCountdate(Date countdate) {
        this.countdate = countdate;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Long getMallId() {
        return mallId;
    }

    public void setMallId(Long mallId) {
        this.mallId = mallId;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getPersonUnid() {
        return personUnid;
    }

    public void setPersonUnid(String personUnid) {
        this.personUnid = personUnid == null ? null : personUnid.trim();
    }

    public String getShowbodyPicExt() {
        return showbodyPicExt;
    }

    public void setShowbodyPicExt(String showbodyPicExt) {
        this.showbodyPicExt = showbodyPicExt == null ? null : showbodyPicExt.trim();
    }

    public Short getStatus() {
        return status;
    }

    public void setStatus(Short status) {
        this.status = status;
    }

    public String getFacePath() {
        return facePath;
    }

    public void setFacePath(String facePath) {
        this.facePath = facePath == null ? null : facePath.trim();
    }

    public String getBodyPath() {
        return bodyPath;
    }

    public void setBodyPath(String bodyPath) {
        this.bodyPath = bodyPath == null ? null : bodyPath.trim();
    }

    public String getFaceFeature() {
        return faceFeature;
    }

    public void setFaceFeature(String faceFeature) {
        this.faceFeature = faceFeature == null ? null : faceFeature.trim();
    }

    public String getBodyFeature() {
        return bodyFeature;
    }

    public void setBodyFeature(String bodyFeature) {
        this.bodyFeature = bodyFeature == null ? null : bodyFeature.trim();
    }

    public String getTrackInfo() {
        return trackInfo;
    }

    public void setTrackInfo(String trackInfo) {
        this.trackInfo = trackInfo == null ? null : trackInfo.trim();
    }

    public Integer getTrackTime() {
        return trackTime;
    }

    public void setTrackTime(Integer trackTime) {
        this.trackTime = trackTime;
    }

    public Short getHappyConf() {
        return happyConf;
    }

    public void setHappyConf(Short happyConf) {
        this.happyConf = happyConf;
    }

    public Short getHistoryArrivalCount() {
        return historyArrivalCount;
    }

    public void setHistoryArrivalCount(Short historyArrivalCount) {
        this.historyArrivalCount = historyArrivalCount;
    }

    public Short getTodayArrivalCount() {
        return todayArrivalCount;
    }

    public void setTodayArrivalCount(Short todayArrivalCount) {
        this.todayArrivalCount = todayArrivalCount;
    }

    public String getTrackPath() {
        return trackPath;
    }

    public void setTrackPath(String trackPath) {
        this.trackPath = trackPath == null ? null : trackPath.trim();
    }

    public String getUnid() {
        return unid;
    }

    public void setUnid(String unid) {
        this.unid = unid == null ? null : unid.trim();
    }

    public Float getFaceScore() {
        return faceScore;
    }

    public void setFaceScore(Float faceScore) {
        this.faceScore = faceScore;
    }

    public Short getFaceType() {
        return faceType;
    }

    public void setFaceType(Short faceType) {
        this.faceType = faceType;
    }

    public Long getFlag() {
        return flag;
    }

    public void setFlag(Long flag) {
        this.flag = flag;
    }

    public Device getDevice() {
        return device;
    }

    public void setDevice(Device device) {
        this.device = device;
    }

    public Channel getChannel() {
        return channel;
    }

    public void setChannel(Channel channel) {
        this.channel = channel;
    }

    public Gate getGate() {
        return gate;
    }

    public void setGate(Gate gate) {
        this.gate = gate;
    }

    public Person getPerson() {
        return person;
    }

    public void setPerson(Person person) {
        this.person = person;
    }

    public Mall getMall() {
        return mall;
    }

    public void setMall(Mall mall) {
        this.mall = mall;
    }

    public Account getAccount() {
        return account;
    }

    public void setAccount(Account account) {
        this.account = account;
    }
}
